OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakter",
    "No contacts in here" : "Det finns inga kontakter här",
    "Name" : "Namn",
    "Organization" : "Organisation",
    "Title" : "Rubrik",
    "Add field ..." : "Lägg till fält ...",
    "Import" : "Importera",
    "Add contact" : "Lägg till en kontakt",
    "No search result for {query}" : "Inget sökresultat för {query}",
    "All contacts" : "Alla kontakter",
    "Not grouped" : "Inte grupperad",
    "Post Office Box" : "Postbox",
    "Postal Code" : "Postkod",
    "City" : "Stad",
    "State or province" : "Stat eller provins",
    "Country" : "Land",
    "Address" : "Adress",
    "(new group)" : "(ny grupp)",
    "New contact" : "Ny kontakt",
    "{addressbook} shared by {owner}" : "{addressbook} delad av {owner}",
    "Nickname" : "Smeknamn",
    "Notes" : "Anteckningar",
    "Website" : "Webbplats",
    "Federated Cloud ID" : "Federerad Cloud ID",
    "Home" : "Hem",
    "Work" : "Arbete",
    "Other" : "Annat",
    "Groups" : "Grupper",
    "Birthday" : "Födelsedag",
    "Email" : "E-post",
    "Instant messaging" : "Snabbmeddelanden",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax hem",
    "Fax work" : "Fax arbete",
    "Pager" : "Personsökare",
    "Voice" : "Röst",
    "Settings" : "Inställningar"
},
"nplurals=2; plural=(n != 1);");
